==> vaccine_1.0.0.tar.gz: vaccine/README.md <==
<!-- badges: start -->
  ![GitHub R package version](https://img.shields.io/github/r-package/v/Avi-Kenny/vaccine)
  [![CRAN status](https://www.r-pkg.org/badges/version/vaccine)](https://CRAN.R-project.org/package=vaccine)
  ![GitHub](https://img.shields.io/github/license/Avi-Kenny/vaccine)
  [![R-CMD-check](https://github.com/Avi-Kenny/vaccine/actions/workflows/R-CMD-check.yml/badge.svg)](https://github.com/Avi-Kenny/vaccine/actions/workflows/R-CMD-check.yml)
  [![Codecov test coverage](https://codecov.io/gh/Avi-Kenny/vaccine/branch/master/graph/badge.svg)](https://app.codecov.io/gh/Avi-Kenny/vaccine?branch=master)
  [![](https://cranlogs.r-pkg.org/badges/vaccine)](https://CRAN.R-project.org/package=vaccine)
<!-- badges: end -->


# vaccine <img src='man/figures/logo.png' align="right" height="150" />

Statistical tools for immune correlates analysis of vaccine clinical trial data

## Overview

**vaccine** is an open-source R package containing various semiparametric and nonparametric statistical tools for immune correlates analysis of vaccine clinical trial data. This includes calculation of summary statistics and estimation of risk, vaccine efficacy, controlled risk, and controlled vaccine efficacy.

## Installation

The latest stable version of **vaccine** can be installed from CRAN using `install.packages()`. The current development version can be installed using `devtools::install_github()`:

```R
install.packages("vaccine")
devtools::install_github(repo="Avi-Kenny/vaccine")
```

<!--## Documentation

The full package documentation can be found at [https://avi-kenny.github.io/SimEngine/](https://avi-kenny.github.io/SimEngine/). All of the CRAN documentation (i.e. the function reference and vignettes) can also be found here.-->

## Bugs reports and feature requests

To submit a bug report or request a new feature, please submit a new [GitHub Issue](https://github.com/Avi-Kenny/vaccine/issues).

==> vaccine_1.2.1.tar.gz: vaccine/README.md <==
<!-- badges: start -->
  ![GitHub R package version](https://img.shields.io/github/r-package/v/Avi-Kenny/vaccine)
  [![CRAN status](https://www.r-pkg.org/badges/version/vaccine)](https://CRAN.R-project.org/package=vaccine)
  ![GitHub](https://img.shields.io/github/license/Avi-Kenny/vaccine)
  [![R-CMD-check](https://github.com/Avi-Kenny/vaccine/actions/workflows/R-CMD-check.yml/badge.svg)](https://github.com/Avi-Kenny/vaccine/actions/workflows/R-CMD-check.yml)
  [![Codecov test coverage](https://codecov.io/gh/Avi-Kenny/vaccine/branch/master/graph/badge.svg)](https://app.codecov.io/gh/Avi-Kenny/vaccine?branch=master)
  [![](https://cranlogs.r-pkg.org/badges/vaccine)](https://CRAN.R-project.org/package=vaccine)
<!-- badges: end -->


# vaccine <img src='man/figures/logo.png' align="right" height="150" />

Statistical tools for immune correlates analysis of vaccine clinical trial data

## Overview

**vaccine** is an open-source R package containing various semiparametric and nonparametric statistical tools for immune correlates analysis of vaccine clinical trial data. This includes calculation of summary statistics and estimation of risk, vaccine efficacy, controlled risk, and controlled vaccine efficacy.

## Installation

The latest stable version of **vaccine** can be installed from CRAN using `install.packages()`:

```R
install.packages("vaccine")
```

The current development version can be installed using `devtools::install_github()`:

```R
devtools::install_github(repo="Avi-Kenny/vaccine")
```

<!--## Documentation

The full package documentation can be found at [https://avi-kenny.github.io/SimEngine/](https://avi-kenny.github.io/SimEngine/). All of the CRAN documentation (i.e. the function reference and vignettes) can also be found here.-->

## Bugs reports and feature requests

To submit a bug report or request a new feature, please submit a new [GitHub Issue](https://github.com/Avi-Kenny/vaccine/issues).
